@@ -1,34 +1,6 @@
 #!/usr/bin/python3
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2020-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2020-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 """
 Univention Corporate Server localization tool to extract, update, and compile
 GNU gettext Portable Objects (PO files) to Message Objects (MO files).
@@ -41,20 +13,20 @@ import sys
 from . import l10n as tlh
 
 
-def main():  # type: () -> None
+def main() -> None:
     cmd = os.path.basename(sys.argv[0])
     parse_args(cmd)
 
 
-def main_build():  # type: () -> None
+def main_build() -> None:
     parse_args("univention-l10n-build")
 
 
-def main_install():  # type: () -> None
+def main_install() -> None:
     parse_args("univention-l10n-install")
 
 
-def parse_args(cmd):  # type: (str) -> None
+def parse_args(cmd: str) -> None:
     parser_common = argparse.ArgumentParser(add_help=False)
     group = parser_common.add_argument_group("debhelper", "Common debhelper options")
     # group.add_argument("--verbose", "-v", action="store_true", help="Verbose mode: show all commands that modify the package build directory.")
@@ -92,7 +64,7 @@ def parse_args(cmd):  # type: (str) -> None
     args.func(args)
 
 
-def build(args):  # type: (argparse.Namespace) -> None
+def build(args: argparse.Namespace) -> None:
     """
     Generate GNU gettext Portable Objects (PO files) from debian/\\*.univention-l10n files
 
@@ -134,7 +106,7 @@ def build(args):  # type: (argparse.Namespace) -> None
         tlh.update_package_translation_files(module, cwd, args.pot)
 
 
-def install(args):  # type: (argparse.Namespace) -> None
+def install(args: argparse.Namespace) -> None:
     """
     Generate and install GNU gettext Message Objects (MO files) from debian/\\*.univention-l10n files.
 
